package ApplicationHistoryDatabaseTest;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import applicationRepository.ApplicationHistoryDatabase;
import dataTypes.ResourceType;

public class ApplicationHistoryDatabaseTest {

	ApplicationHistoryDatabase db = null;
	
	private ResourceType resource = ResourceType.memory;

	@Before
	public void setUp() {
		db = new ApplicationHistoryDatabase(
				"jdbc:h2:file:/tmp/integrade_test/database/ApplicationHistoryDatabaseTest");
	}
	
	@After
	public void tearDown() {
		db.purge();
	}

	@Test
	public void testSize() {
		Assert.assertEquals(0, db.size("testApp1"));
		db.addExecution("testApp1", 0, 0, 0);
		Assert.assertEquals(1, db.size("testApp1"));
		for(int i = 0; i < 10; i++) {
			db.addExecution("testApp1", 0, 0, 0);
		}
		Assert.assertEquals(11, db.size("testApp1"));
	}
	
	@Test
	public void testMean() {
		Assert.assertEquals(0.0,  db.getMean("testApp1", resource));
		db.addExecution("testApp1", 0, 1, 0);
		Assert.assertEquals(1.0, db.getMean("testApp1", resource));
		db.addExecution("testApp1", 0, 2, 0);
		Assert.assertEquals(1.5, db.getMean("testApp1", resource));
	}
	
	@Test
	public void testMedian() {
		Assert.assertEquals(0.0,  db.getMedian("testApp1", resource));
		db.addExecution("testApp1", 0, 1, 0);
		Assert.assertEquals(1.0, db.getMedian("testApp1", resource));
		db.addExecution("testApp1", 0, 2, 0);
		Assert.assertEquals(2.0, db.getMedian("testApp1", resource));
		db.addExecution("testApp1", 0, 20, 0);
		Assert.assertEquals(2.0, db.getMedian("testApp1", resource));
		
		db.addExecution("testApp2", 0, 1, 0);
		db.addExecution("testApp2", 0, 20, 0);
		Assert.assertEquals(20.0, db.getMedian("testApp2", resource));
	}
	
	@Test
	public void testStandardDeviation() {
		Assert.assertEquals(0.0, db.getStandardDeviation("testApp1", resource));
		db.addExecution("testApp1", 0, 1, 0);
		db.addExecution("testApp1", 0, 1, 0);
		db.addExecution("testApp1", 0, 1, 0);
		Assert.assertEquals(0.0, db.getStandardDeviation("testApp1", resource));
		db.addExecution("testApp1", 0, 10, 0);
		Assert.assertEquals(4.5, db.getStandardDeviation("testApp1", resource));
	}

}
