package resourcePredictor;

import mocks.ApplicationHistoryDatabaseMock;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import dataTypes.ResourceType;

public class MedianPredictorTest {

	private ApplicationHistoryDatabaseMock mock = null;

	private MedianPredictor predictor = null;
	
	private double epsilon = 10e-5;

	@Before
	public void setUp() throws Exception {
		mock = new ApplicationHistoryDatabaseMock();
		predictor = new MedianPredictor(mock);
	}

	@Test
	public void testPredictNext() {
		double epsilon = 10e-7;
		mock.setSize(5);
		mock.setMedian(ResourceType.executionTime, 1);
		mock.setMedian(ResourceType.memory, 2);
		
		double execTime = predictor.predictNext("testApp").getExecutionTime();
		long memory = predictor.predictNext("testApp").getMemory();
		
		Assert.assertEquals(1, execTime, epsilon);
		Assert.assertEquals(2, memory, epsilon);
	}
	
	@Test
	public void predictionOfFractionaryValueShouldBeTheCeil() {
		mock.setSize(5);
		mock.setMedian(ResourceType.executionTime, 1.5);
		mock.setMedian(ResourceType.memory, 1.5);
		
		double execTime = predictor.predictNext("testApp").getExecutionTime();
		long memory = predictor.predictNext("testApp").getMemory();
		
		Assert.assertEquals(1.5, execTime, epsilon);
		Assert.assertEquals(2, memory, epsilon);
	}
}
